@@ -11,6 +11,7 @@
  */
 #include <errno.h>
 #include <stdbool.h>
+#include <stddef.h>
 #include <stdint.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -304,12 +305,17 @@ static int HXhmap_layout(struct HXhmap *hmap, unsigned int power)
 	if (hmap->bk_array != NULL) {
 		HXhmap_move(bk_array, bk_number, hmap);
 		old_array = hmap->bk_array;
+		/*
+		 * It is ok to increment the TID this late. @map->bk_array is
+		 * only emptied, and the new @bk_array is not yet visible to
+		 * traversers, so no elements appear twice.
+		 */
+		++hmap->tid;
 	}
 	hmap->power    = power;
 	hmap->min_load = (power != 0) ? HXhash_primes[power] / 4 : 0;
 	hmap->max_load = x_frac(7, 10, HXhash_primes[power]);
 	hmap->bk_array = bk_array;
-	++hmap->tid;
 	free(old_array);
 	return 1;
 }
